## Cookies Policy

Ai sensi del Decreto Legislativo n ° 196/2003, che ha sostituito la legge n ° 675/1996 in materia di protezione dei dati personali, Vi informiamo che proseguendo la navigazione su questo sito voi acconsentite al trattamento dei vostri dati personali (i dati sensibili non saranno trattati in alcun modo) acquisiti da GeoSolutions SAS tramite strumenti elettronici e/o automatici. In ogni caso, è possibile esercitare i diritti concessi all'utente ai sensi del Decreto Legislativo n ° 196/2003 (accesso ai dati, aggiornamento, integrazione, cancellazione). Facendo clic sul pulsante “Accetto”, si dichiara di aver letto questo testo e di acconsentire al trattamento dei dati personali. In qualsiasi momento è possibile chiedere alla redazione di GeoSolutions SAS del sito di cancellarti dal servizio seguendo le istruzioni alla fine di ogni messaggio.

#### Cosa sono i Cookies?

Un cookie è un file di testo che un sito web salva sul browser del computer dell’utente. Solitamente i cookie consentono di memorizzare le preferenze espresse dall’utente per non dover essere reinserite successivamente. Il browser salva l’informazione e la ritrasmette al server del sito nel momento in cui l’utente visita nuovamente quel sito web.

I nostri cookie ci aiutano a:

- Permettere al sito web di lavorare come atteso
- Ricordare le impostazioni durante e tra le visite al sito
- Migliorare la velocità sicurezza del sito
- Permette di condividere le pagine con i social network come Facebook

Non viene fatto uso di cookies per:

- Raccogliere tutte le informazioni di identificazione personale (senza il vostro consenso)
- Raccogliere tutte le informazioni sensibili (senza il tuo esplicito consenso)
- Passare i dati alle reti pubblicitarie
- Passare dati personali a terze parti
- Commissioni di vendita a pagamento

Potete saperne di più su tutti i cookies che utilizziamo qui sotto.

Se le impostazioni del software che si sta utilizzando per la navigazione del sito (il browser) sono regolati per accettare i cookies prendiamo questo, e l'uso continuato del nostro sito web, a significare che si acconsente all'utilizzo di cookies. Se si desidera rimuovere o non usare i cookies dal nostro sito lo si può fare seguendo le indicazioni riportate di seguito, così facendo tuttavia il nostro sito potrebbe non funzionare come ci si aspetterebbe.

#### I nostri Cookies

Utilizziamo i cookie per garantire determinate funzionalità del sito web tra cui:

- Operazioni di Login e successive autenticazioni
- Autenticazione a servizi WMS, WFS, WPS attraverso richieste HTTP

Non è possibile prevenire che questi cookies There is no way to prevent these cookies being set other than to not use our site.

#### Cookies di Terze Parti

Il nostro sito, come molti, include funzionalità e servizi offerti da terze parti. Un comune esempio è l'embed di un video di YouTube. Il nostro sito include i seguenti cookie:

- Google
- Cloudflare

#### Social Website Cookies

Tu puoi facilmente esprimere il tuo gradimento o condividere alcuni contenuti su Facebook e Twitter (abbiamo incluso i pulsanti di condivisione sul nostro sito). I cookies sono stati abilitati per:

- Twitter
- Facebook
- Linkedin
- Google +

Le implicazioni di privacy su questo variano da social network a social network e dipenderanno dalle impostazioni di privacy che avete scelto su queste reti.

#### Disabilitare i Cookies

Di solito è possibile disattivare i cookies modificando le impostazioni del browser per impedire l'uso degli stessi (vedi qui. In questo modo però probabilmente si limiteranno le funzionalità del nostro come di molti dei siti web di tutto il mondo (i cookie sono una componente standard della maggior parte dei siti web moderni).

Potrebbe essere che le tue preoccupazioni relativi ai cookie riguardino i cosiddetti "spyware". Piuttosto che disattivare i cookie nel tuo browser puoi sapere che il software anti-spyware raggiunge lo stesso obiettivo eliminando automaticamente i cookie considerati invasivi. Leggi come gestire i cookie con software antispyware.